% Plots the cobweb diagram which illustrates the solution to x = r*x*(1-x).
function cobweb
global d
d.r = 2; d.dr = 0.05; d.x0 = 0.4; d.dx0 = 0.05; fsize = 14;

%Define x,f(x) values
d.x = linspace(0,1,1000);

%Plot y = f(x) and y = x
figure( 'KeyPressFcn',@keypress );
d.fplot = plot( d.x,f( d.x,d.r ),'b','linewidth',2 ); 
hold on; plot( d.x,d.x,'r-','linewidth',2 );

%Plot cobweb iterations
[d.X,d.Y] = cobweb_iter(d.x0,d.x,d.r);
d.cobwebplotstart = plot( d.X(1),d.X(2),'g*' );
d.cobwebplot = plot( d.X,d.Y,'-','color',[0,0,0],'linewidth',1.5 );

%Axes labels etc
xlabel('x','fontsize',fsize); ylabel('y','fontsize',fsize);
d.title = title([' x_{n+1} = ',num2str(d.r),'*x_n*(1-x_n)'],'fontsize',fsize);
grid on; box on; set(gca,'fontsize',fsize);

%%

%May's logistic function f(x)
function y = f(x,r)
y = r*x.*( 1 - x );

%%

% Determine N iterations from a random starting position
function [X,Y] = cobweb_iter(x0,x,r)
N = 500; X = x0; Y = X;
for n=1:N
    X = [ X,X(end) ]; Y = [ Y,f( X(end),r ) ];
    X = [ X,Y(end) ]; Y = [ Y,Y(end) ];
end

%%

%Plot update function
function keypress_update
global d
[d.X,d.Y] = cobweb_iter(d.x0,d.x,d.r);
set( d.fplot,'xdata',d.x,'ydata',f( d.x,d.r ) );
set( d.cobwebplotstart,'xdata',d.X(1),'ydata',d.Y(1) );
set( d.cobwebplot,'xdata',d.X,'ydata',d.Y);
set( d.title,'string',[' x_{n+1} = ',num2str(d.r),'*x_n*(1-x_n)']);

%%

%Function which executes when a key is pressed
function keypress(fig,evnt)
global d
if strcmp(get(fig,'currentkey'),'p')==1
    print(gcf,['cobweb x0=',strrep(num2str(d.x0),'.','p'),...
        ' r=',strrep(num2str(d.r),'.','p'),'.png'],'-dpng','-r300');
elseif strcmp(get(fig,'currentkey'),'uparrow')==1
    d.r = d.r + d.dr; if d.r >4; d.r = 4; end
    keypress_update
elseif strcmp(get(fig,'currentkey'),'downarrow')==1
    d.r = d.r - d.dr; if d.r <0 ; d.r = 0; end
    keypress_update
elseif strcmp(get(fig,'currentkey'),'rightarrow')==1
    d.x0 = d.x0 + d.dx0; if d.x0 >1; d.x0=1; end
    keypress_update
elseif strcmp(get(fig,'currentkey'),'leftarrow')==1
    d.x0 = d.x0 - d.dx0; if d.x0 <0; d.x0=0; end
    keypress_update 
elseif strcmp(get(fig,'return'),'uparrow')==1
    keypress_update
end

%End of code